@@ -1,4 +1,6 @@
 from datetime import datetime
+from datetime import timedelta
+from datetime import timezone
 from io import BytesIO
 from json import dumps
 from logging import Logger
@@ -187,7 +189,7 @@ def bbcode_to_html(bbcode: str) -> str:
                     child_new_img: Tag = Tag(
                         name="img",
                         attrs={"alt": user, "title": user,
-                               "src": f"//a.furaffinity.net/{datetime.now():%Y%m%d}/{clean_username(user)}.gif"})
+                               "src": f"/user/{clean_username(user)}/icon"})
                     child_new.insert(0, child_new_img)
                     if m_[2]:
                         child_new.insert(1, f"\xA0{m_[2]}")
@@ -241,14 +243,14 @@ def bbcode_to_html(bbcode: str) -> str:
     parser.add_simple_formatter(
         "iconusername",
         f'<a class=iconusername href="/user/%(value)s">'
-        f'<img alt="%(value)s" title="%(value)s" src="//a.furaffinity.net/{datetime.now():%Y%m%d}/%(value)s.gif">'
+        f'<img alt="%(value)s" title="%(value)s" src="/user/%(value)s/icon">'
         f'%(value)s'
         f'</a>'
     )
     parser.add_simple_formatter(
         "usernameicon",
         f'<a class=iconusername href="/user/%(value)s">'
-        f'<img alt="%(value)s" title="%(value)s" src="//a.furaffinity.net/{datetime.now():%Y%m%d}/%(value)s.gif">'
+        f'<img alt="%(value)s" title="%(value)s" src="/user/%(value)s/icon">'
         f'</a>'
     )
     parser.add_simple_formatter("linkusername", '<a class=linkusername href="/user/%(value)s">%(value)s</a>')
@@ -270,6 +272,7 @@ def clean_html(html: str) -> str:
     for icon in html_parsed.select("a.iconusername > img"):
         icon.attrs["hidden"] = "true"
         icon.attrs["onload"] = "this.hidden = false"
+        icon.attrs["src"] = f"/user/{clean_username(icon.attrs['title'])}/icon/"
     for link in html_parsed.select("a[href*='furaffinity.net']"):
         link["href"] = "/" + fa_link.sub("", link.attrs["href"]).strip("/")
     return str(html_parsed)
@@ -531,7 +534,7 @@ async def serve_user(request: Request, username: str):
         "journals_length": user_stats["journals"],
         "userpage": prepare_html(user_entry.get("USERPAGE", ""), settings.database.use_bbcode()),
         "userpage_bbcode": user_entry.get("USERPAGE", None) if settings.database.use_bbcode() else None,
-        "icon": f"//a.furaffinity.net/{datetime.now():%Y%m%d}/{clean_username(username)}.gif",
+        "icon": f"/user/{username}/icon",
         "in_database": bool(user_entry),
         "prev": p,
         "next": n,
@@ -541,11 +544,12 @@ async def serve_user(request: Request, username: str):
 
 @app.get("/user/{username}/icon/")
 @app.get("/user/{username}/thumbnail/")
-async def serve_user_thumbnail(request: Request, username: str):
+async def serve_user_thumbnail(username: str):
     if username != (username_clean := clean_username(username)):
         return RedirectResponse(app.url_path_for(serve_user_thumbnail.__name__, username=username_clean))
 
-    return RedirectResponse(f"https://a.furaffinity.net/{datetime.now():%Y%m%d}/{username}.gif")
+    server_time: datetime = datetime.now(timezone(timedelta(hours=-8)))
+    return RedirectResponse(f"https://a.furaffinity.net/{server_time:%Y%m%d}/{username}.gif")
 
 
 @app.get("/search/{table}/", response_class=HTMLResponse)
